pub struct CommandExamples;Expand description
Enhanced CLI help text with detailed examples and usage patterns This module provides rich help content for all RustChain CLI commands
Implementations
Sourceimpl CommandExamples
impl CommandExamples
Sourcepub fn mission_help() -> &'static str
pub fn mission_help() -> &'static str
Get detailed help for mission commands
Sourcepub fn tools_help() -> &'static str
pub fn tools_help() -> &'static str
Get detailed help for tools commands
Sourcepub fn safety_help() -> &'static str
pub fn safety_help() -> &'static str
Get detailed help for safety commands
Sourcepub fn policy_help() -> &'static str
pub fn policy_help() -> &'static str
Get detailed help for policy commands
Sourcepub fn interactive_help() -> &'static str
pub fn interactive_help() -> &'static str
Get detailed help for interactive mode
Sourcepub fn enterprise_help() -> &'static str
pub fn enterprise_help() -> &'static str
Get detailed help for enterprise commands
Sourcepub fn features_help() -> &'static str
pub fn features_help() -> &'static str
Get comprehensive feature help